@@ -1,10 +1,20 @@
 # -*- coding: utf-8 -*-
-from .files import InputFile
 from luckydonaldUtils.encoding import unicode_type, to_unicode as u
 from luckydonaldUtils.exceptions import assert_type_or_raise
 from . import Sendable
 
 __author__ = 'luckydonald'
+__all__ = [
+    'InputMedia',
+    'InputMediaWithThumb',
+    'InputMediaPlayable',
+    'InputMediaVideolike',
+    'InputMediaPhoto',
+    'InputMediaVideo',
+    'InputMediaAnimation',
+    'InputMediaAudio',
+    'InputMediaDocument',
+]
 
 
 class InputMedia(Sendable):
@@ -20,7 +30,7 @@ class InputMedia(Sendable):
     :type  type: str|unicode
 
     :param media: File to send. Pass a file_id to send a file that exists on the Telegram servers (recommended), pass an HTTP URL for Telegram to get a file from the Internet, or pass "attach://<file_attach_name>" to upload a new one using multipart/form-data under <file_attach_name> name. More info on Sending Files »
-    :type  media: str|unicode
+    :type  media: pytgbot.api_types.sendable.files.InputFile | str|unicode
 
 
     Optional keyword parameters:
@@ -48,7 +58,7 @@ class InputMedia(Sendable):
         :type  type: str|unicode
 
         :param media: File to send. Pass a file_id to send a file that exists on the Telegram servers (recommended), pass an HTTP URL for Telegram to get a file from the Internet, or pass "attach://<file_attach_name>" to upload a new one using multipart/form-data under <file_attach_name> name. More info on Sending Files »
-        :type  media: str|unicode
+        :type  media: pytgbot.api_types.sendable.files.InputFile | str|unicode
 
 
         Optional keyword parameters:
@@ -63,10 +73,11 @@ class InputMedia(Sendable):
         :type  caption_entities: list of pytgbot.api_types.receivable.media.MessageEntity
         """
         super(InputMedia, self).__init__()
-
+        from .files import InputFile
+        from ..receivable.media import MessageEntity
         assert_type_or_raise(type, unicode_type, parameter_name="type")
         self.type = type
-        assert_type_or_raise(media, unicode_type, parameter_name="media")
+        assert_type_or_raise(media, InputFile, unicode_type, parameter_name="media")
         self.media = media
         assert_type_or_raise(caption, None, unicode_type, parameter_name="caption")
         self.caption = caption
@@ -90,10 +101,18 @@ class InputMedia(Sendable):
             return self._raw
         # end if
 
+        from .files import InputFile
+        from ..receivable.media import MessageEntity
         array = super(InputMedia, self).to_array()
 
         array['type'] = u(self.type)  # py2: type unicode, py3: type str
-        array['media'] = u(self.media)  # py2: type unicode, py3: type str
+        if isinstance(self.media, InputFile):
+            array['media'] = self.media.to_array()  # type InputFile
+        elif isinstance(self.media, str):
+            array['media'] = u(self.media)  # py2: type unicode, py3: type str
+        else:
+            raise TypeError('Unknown type, must be one of InputFile, str.')
+        # end if
         if self.caption is not None:
             array['caption'] = u(self.caption)  # py2: type unicode, py3: type str
         # end if
@@ -116,10 +135,17 @@ class InputMedia(Sendable):
         :rtype: dict
         """
         assert_type_or_raise(array, dict, parameter_name="array")
-
+        from .files import InputFile
+        from ..receivable.media import MessageEntity
         data = Sendable.validate_array(array)
         data['type'] = u(array.get('type'))
-        data['media'] = u(array.get('media'))
+        if isinstance(array.get('media'), InputFile):
+            data['thumb'] = None  # will be filled later by get_request_data()
+        elif isinstance(array.get('media'), str):
+            data['media'] = u(array.get('media'))
+        else:
+            raise TypeError('Unknown type, must be one of InputFile, str.')
+        # end if
         data['caption'] = u(array.get('caption')) if array.get('caption') is not None else None
         data['parse_mode'] = u(array.get('parse_mode')) if array.get('parse_mode') is not None else None
         data['caption_entities'] = MessageEntity.from_array_list(array.get('caption_entities'), list_level=1) if array.get('caption_entities') is not None else None
@@ -206,7 +232,7 @@ class InputMedia(Sendable):
 
 class InputMediaWithThumb(InputMedia):
     """
-    This object represents the content of a media message to be sent.
+    InputMedia but with a thumb field.
 
     https://core.telegram.org/bots/api#inputmedia
 
@@ -217,7 +243,7 @@ class InputMediaWithThumb(InputMedia):
     :type  type: str|unicode
 
     :param media: File to send. Pass a file_id to send a file that exists on the Telegram servers (recommended), pass an HTTP URL for Telegram to get a file from the Internet, or pass "attach://<file_attach_name>" to upload a new one using multipart/form-data under <file_attach_name> name. More info on Sending Files »
-    :type  media: str|unicode
+    :type  media: pytgbot.api_types.sendable.files.InputFile | str|unicode
 
     :param thumb: Thumbnail of the file sent; can be ignored if thumbnail generation for the file is supported server-side. The thumbnail should be in JPEG format and less than 200 kB in size. A thumbnail's width and height should not exceed 320. Ignored if the file is not uploaded using multipart/form-data. Thumbnails can't be reused and can be only uploaded as a new file.
     :type  thumb: pytgbot.api_types.sendable.files.InputFile | str|unicode
@@ -266,9 +292,10 @@ class InputMediaWithThumb(InputMedia):
         # end if
     # end def
 
+    # noinspection PyShadowingBuiltins
     def __init__(self, type, media, thumb=None, caption=None, parse_mode=None, caption_entities=None):
         """
-        This object represents the content of a media message to be sent.
+        InputMedia but with a thumb field.
 
         https://core.telegram.org/bots/api#inputmedia
 
@@ -279,7 +306,7 @@ class InputMediaWithThumb(InputMedia):
         :type  type: str|unicode
 
         :param media: File to send. Pass a file_id to send a file that exists on the Telegram servers (recommended), pass an HTTP URL for Telegram to get a file from the Internet, or pass "attach://<file_attach_name>" to upload a new one using multipart/form-data under <file_attach_name> name. More info on Sending Files »
-        :type  media: str|unicode
+        :type  media: pytgbot.api_types.sendable.files.InputFile | str|unicode
 
         :param thumb: Thumbnail of the file sent; can be ignored if thumbnail generation for the file is supported server-side. The thumbnail should be in JPEG format and less than 200 kB in size. A thumbnail's width and height should not exceed 320. Ignored if the file is not uploaded using multipart/form-data. Thumbnails can't be reused and can be only uploaded as a new file.
         :type  thumb: pytgbot.api_types.sendable.files.InputFile | str|unicode
@@ -296,8 +323,7 @@ class InputMediaWithThumb(InputMedia):
         :param caption_entities: Optional. List of special entities that appear in the caption, which can be specified instead of parse_mode
         :type  caption_entities: list of pytgbot.api_types.receivable.media.MessageEntity
         """
-        super(InputMediaWithThumb, self).__init__(type, media, caption, parse_mode, caption_entities)
-
+        super(InputMediaWithThumb, self).__init__(type=type, media=media, caption=caption, parse_mode=parse_mode, caption_entities=caption_entities)
         # 'type' is set by InputMedia base class
         # 'media' is set by InputMedia base class
         assert_type_or_raise(thumb, None, InputFile, unicode_type, parameter_name="thumb")
@@ -322,20 +348,12 @@ class InputMediaWithThumb(InputMedia):
         # end if
 
         array = super(InputMediaWithThumb, self).to_array()
-
-        # 'type' given by superclass
-        # 'media' given by superclass
-        if isinstance(self.thumb, InputFile):
-            array['thumb'] = self.thumb.to_array()  # type InputFile
-        elif isinstance(self.thumb, str):
-            array['thumb'] = u(self.thumb)  # py2: type unicode, py3: type str
-        else:
-            raise TypeError('Unknown type, must be one of InputFile, str.')
-        # end if
-        # 'caption' given by superclass
-        # 'parse_mode' given by superclass
-        # 'caption_entities' given by superclass
-
+        # 'type' is handled by superclass
+        array['media'] = u(self.media)  # py2: type unicode, py3: type str
+        if self.caption is not None:
+            array['caption'] = u(self.caption)  # py2: type unicode, py3: type str
+        if self.parse_mode is not None:
+            array['parse_mode'] = u(self.parse_mode)  # py2: type unicode, py3: type str
         return array
     # end def to_array
 
@@ -348,20 +366,11 @@ class InputMediaWithThumb(InputMedia):
         :rtype: dict
         """
         assert_type_or_raise(array, dict, parameter_name="array")
-
         data = InputMedia.validate_array(array)
-        # 'type' is given by class type
-        # 'media' is given by class type
-        if isinstance(array.get('thumb'), InputFile):
-            data['thumb'] = None  # will be filled later by get_request_data()
-        elif isinstance(array.get('thumb'), str):
-            data['thumb'] = u(array.get('thumb'))
-        else:
-            raise TypeError('Unknown type, must be one of InputFile, str.')
-        # end if
-        # 'caption' is given by class type
-        # 'parse_mode' is given by class type
-        # 'caption_entities' is given by class type
+        # 'type' is handled by the superclass.
+        data['media'] = u(array.get('media'))
+        data['caption'] = u(array.get('caption')) if array.get('caption') is not None else None
+        data['parse_mode'] = u(array.get('parse_mode')) if array.get('parse_mode') is not None else None
         return data
     # end def validate_array
 
@@ -415,7 +424,7 @@ class InputMediaWithThumb(InputMedia):
 
 class InputMediaPlayable(InputMediaWithThumb):
     """
-    This object represents the content of a media message to be sent.
+    InputMedia with a thumb and duration.
 
     https://core.telegram.org/bots/api#inputmedia
 
@@ -426,7 +435,7 @@ class InputMediaPlayable(InputMediaWithThumb):
     :type  type: str|unicode
 
     :param media: File to send. Pass a file_id to send a file that exists on the Telegram servers (recommended), pass an HTTP URL for Telegram to get a file from the Internet, or pass "attach://<file_attach_name>" to upload a new one using multipart/form-data under <file_attach_name> name. More info on Sending Files »
-    :type  media: str|unicode
+    :type  media: pytgbot.api_types.sendable.files.InputFile | str|unicode
 
     :param thumb: Thumbnail of the file sent; can be ignored if thumbnail generation for the file is supported server-side. The thumbnail should be in JPEG format and less than 200 kB in size. A thumbnail's width and height should not exceed 320. Ignored if the file is not uploaded using multipart/form-data. Thumbnails can't be reused and can be only uploaded as a new file.
     :type  thumb: pytgbot.api_types.sendable.files.InputFile | str|unicode
@@ -449,9 +458,10 @@ class InputMediaPlayable(InputMediaWithThumb):
 
 
 
+    # noinspection PyShadowingBuiltins
     def __init__(self, type, media, thumb=None, duration=None, caption=None, parse_mode=None, caption_entities=None):
         """
-        This object represents the content of a media message to be sent.
+        InputMedia with a thumb and duration.
 
         https://core.telegram.org/bots/api#inputmedia
 
@@ -462,7 +472,7 @@ class InputMediaPlayable(InputMediaWithThumb):
         :type  type: str|unicode
 
         :param media: File to send. Pass a file_id to send a file that exists on the Telegram servers (recommended), pass an HTTP URL for Telegram to get a file from the Internet, or pass "attach://<file_attach_name>" to upload a new one using multipart/form-data under <file_attach_name> name. More info on Sending Files »
-        :type  media: str|unicode
+        :type  media: pytgbot.api_types.sendable.files.InputFile | str|unicode
 
         :param thumb: Thumbnail of the file sent; can be ignored if thumbnail generation for the file is supported server-side. The thumbnail should be in JPEG format and less than 200 kB in size. A thumbnail's width and height should not exceed 320. Ignored if the file is not uploaded using multipart/form-data. Thumbnails can't be reused and can be only uploaded as a new file.
         :type  thumb: pytgbot.api_types.sendable.files.InputFile | str|unicode
@@ -482,8 +492,7 @@ class InputMediaPlayable(InputMediaWithThumb):
         :param caption_entities: Optional. List of special entities that appear in the caption, which can be specified instead of parse_mode
         :type  caption_entities: list of pytgbot.api_types.receivable.media.MessageEntity
         """
-        super(InputMediaPlayable, self).__init__(type, media, thumb, caption, parse_mode, caption_entities)
-
+        super(InputMediaPlayable, self).__init__(type=type, media=media, thumb=thumb, caption=caption, parse_mode=parse_mode, caption_entities=caption_entities)
         # 'type' is set by InputMediaWithThumb base class
         # 'media' is set by InputMediaWithThumb base class
         # 'thumb' is set by InputMediaWithThumb base class
@@ -532,7 +541,6 @@ class InputMediaPlayable(InputMediaWithThumb):
         :rtype: dict
         """
         assert_type_or_raise(array, dict, parameter_name="array")
-
         data = InputMediaWithThumb.validate_array(array)
         # 'type' is given by class type
         # 'media' is given by class type
@@ -607,7 +615,7 @@ class InputMediaVideolike(InputMediaPlayable):
     :type  type: str|unicode
 
     :param media: File to send. Pass a file_id to send a file that exists on the Telegram servers (recommended), pass an HTTP URL for Telegram to get a file from the Internet, or pass "attach://<file_attach_name>" to upload a new one using multipart/form-data under <file_attach_name> name. More info on Sending Files »
-    :type  media: str|unicode
+    :type  media: pytgbot.api_types.sendable.files.InputFile | str|unicode
 
     :param thumb: Thumbnail of the file sent; can be ignored if thumbnail generation for the file is supported server-side. The thumbnail should be in JPEG format and less than 200 kB in size. A thumbnail's width and height should not exceed 320. Ignored if the file is not uploaded using multipart/form-data. Thumbnails can't be reused and can be only uploaded as a new file.
     :type  thumb: pytgbot.api_types.sendable.files.InputFile | str|unicode
@@ -636,6 +644,7 @@ class InputMediaVideolike(InputMediaPlayable):
 
 
 
+    # noinspection PyShadowingBuiltins
     def __init__(self, type, media, thumb=None, duration=None, width=None, height=None, caption=None, parse_mode=None, caption_entities=None):
         """
         This object represents the content of a media message to be sent.
@@ -649,7 +658,7 @@ class InputMediaVideolike(InputMediaPlayable):
         :type  type: str|unicode
 
         :param media: File to send. Pass a file_id to send a file that exists on the Telegram servers (recommended), pass an HTTP URL for Telegram to get a file from the Internet, or pass "attach://<file_attach_name>" to upload a new one using multipart/form-data under <file_attach_name> name. More info on Sending Files »
-        :type  media: str|unicode
+        :type  media: pytgbot.api_types.sendable.files.InputFile | str|unicode
 
         :param thumb: Thumbnail of the file sent; can be ignored if thumbnail generation for the file is supported server-side. The thumbnail should be in JPEG format and less than 200 kB in size. A thumbnail's width and height should not exceed 320. Ignored if the file is not uploaded using multipart/form-data. Thumbnails can't be reused and can be only uploaded as a new file.
         :type  thumb: pytgbot.api_types.sendable.files.InputFile | str|unicode
@@ -675,8 +684,7 @@ class InputMediaVideolike(InputMediaPlayable):
         :param caption_entities: Optional. List of special entities that appear in the caption, which can be specified instead of parse_mode
         :type  caption_entities: list of pytgbot.api_types.receivable.media.MessageEntity
         """
-        super(InputMediaVideolike, self).__init__(type, media, thumb, duration, caption, parse_mode, caption_entities)
-
+        super(InputMediaVideolike, self).__init__(type=type, media=media, thumb=thumb, duration=duration, caption=caption, parse_mode=parse_mode, caption_entities=caption_entities)
         # 'type' is set by InputMediaPlayable base class
         # 'media' is set by InputMediaPlayable base class
         # 'thumb' is set by InputMediaPlayable base class
@@ -732,7 +740,6 @@ class InputMediaVideolike(InputMediaPlayable):
         :rtype: dict
         """
         assert_type_or_raise(array, dict, parameter_name="array")
-
         data = InputMediaPlayable.validate_array(array)
         # 'type' is given by class type
         # 'media' is given by class type
@@ -806,7 +813,7 @@ class InputMediaPhoto(InputMedia):
     Parameters:
 
     :param media: File to send. Pass a file_id to send a file that exists on the Telegram servers (recommended), pass an HTTP URL for Telegram to get a file from the Internet, or pass "attach://<file_attach_name>" to upload a new one using multipart/form-data under <file_attach_name> name. More info on Sending Files »
-    :type  media: str|unicode
+    :type  media: pytgbot.api_types.sendable.files.InputFile | str|unicode
 
 
     Optional keyword parameters:
@@ -821,6 +828,7 @@ class InputMediaPhoto(InputMedia):
     :type  caption_entities: list of pytgbot.api_types.receivable.media.MessageEntity
     """
 
+    # noinspection PyShadowingBuiltins
     def __init__(self, media, caption=None, parse_mode=None, caption_entities=None):
         """
         Represents a photo to be sent.
@@ -831,7 +839,7 @@ class InputMediaPhoto(InputMedia):
         Parameters:
 
         :param media: File to send. Pass a file_id to send a file that exists on the Telegram servers (recommended), pass an HTTP URL for Telegram to get a file from the Internet, or pass "attach://<file_attach_name>" to upload a new one using multipart/form-data under <file_attach_name> name. More info on Sending Files »
-        :type  media: str|unicode
+        :type  media: pytgbot.api_types.sendable.files.InputFile | str|unicode
 
 
         Optional keyword parameters:
@@ -845,9 +853,8 @@ class InputMediaPhoto(InputMedia):
         :param caption_entities: Optional. List of special entities that appear in the caption, which can be specified instead of parse_mode
         :type  caption_entities: list of pytgbot.api_types.receivable.media.MessageEntity
         """
-        super(InputMediaPhoto, self).__init__('photo', media, caption, parse_mode, caption_entities)
+        super(InputMediaPhoto, self).__init__(type='photo', media=media, caption=caption, parse_mode=parse_mode, caption_entities=caption_entities)
         from ..receivable.media import MessageEntity
-
         # 'type' is set by InputMedia base class
         # 'media' is set by InputMedia base class
         # 'caption' is set by InputMedia base class
@@ -869,6 +876,7 @@ class InputMediaPhoto(InputMedia):
             return self._raw
         # end if
 
+        from ..receivable.media import MessageEntity
         array = super(InputMediaPhoto, self).to_array()
 
         # 'type' given by superclass
@@ -890,7 +898,6 @@ class InputMediaPhoto(InputMedia):
         """
         assert_type_or_raise(array, dict, parameter_name="array")
         from ..receivable.media import MessageEntity
-
         data = InputMedia.validate_array(array)
         # 'type' is given by class type
         # 'media' is given by class type
@@ -958,7 +965,7 @@ class InputMediaVideo(InputMediaVideolike):
     Parameters:
 
     :param media: File to send. Pass a file_id to send a file that exists on the Telegram servers (recommended), pass an HTTP URL for Telegram to get a file from the Internet, or pass "attach://<file_attach_name>" to upload a new one using multipart/form-data under <file_attach_name> name. More info on Sending Files »
-    :type  media: str|unicode
+    :type  media: pytgbot.api_types.sendable.files.InputFile | str|unicode
 
 
     Optional keyword parameters:
@@ -988,6 +995,7 @@ class InputMediaVideo(InputMediaVideolike):
     :type  supports_streaming: bool
     """
 
+    # noinspection PyShadowingBuiltins
     def __init__(self, media, thumb=None, caption=None, parse_mode=None, caption_entities=None, width=None, height=None, duration=None, supports_streaming=None):
         """
         Represents a video to be sent.
@@ -998,7 +1006,7 @@ class InputMediaVideo(InputMediaVideolike):
         Parameters:
 
         :param media: File to send. Pass a file_id to send a file that exists on the Telegram servers (recommended), pass an HTTP URL for Telegram to get a file from the Internet, or pass "attach://<file_attach_name>" to upload a new one using multipart/form-data under <file_attach_name> name. More info on Sending Files »
-        :type  media: str|unicode|pytgbot.api_types.sendable.files.InputFile
+        :type  media: pytgbot.api_types.sendable.files.InputFile | str|unicode
 
 
         Optional keyword parameters:
@@ -1027,10 +1035,9 @@ class InputMediaVideo(InputMediaVideolike):
         :param supports_streaming: Optional. Pass True, if the uploaded video is suitable for streaming
         :type  supports_streaming: bool
         """
-        super(InputMediaVideo, self).__init__('video', media, thumb, caption, parse_mode, caption_entities, width, height, duration)
+        super(InputMediaVideo, self).__init__(type='video', media=media, thumb=thumb, caption=caption, parse_mode=parse_mode, caption_entities=caption_entities, width=width, height=height, duration=duration)
         from ..receivable.media import MessageEntity
         from .files import InputFile
-
         # 'type' is set by InputMediaVideolike base class
         # 'media' is set by InputMediaVideolike base class
         # 'thumb' is set by InputMediaVideolike base class
@@ -1058,6 +1065,8 @@ class InputMediaVideo(InputMediaVideolike):
             return self._raw
         # end if
 
+        from ..receivable.media import MessageEntity
+        from .files import InputFile
         array = super(InputMediaVideo, self).to_array()
 
         # 'type' given by superclass
@@ -1087,7 +1096,6 @@ class InputMediaVideo(InputMediaVideolike):
         assert_type_or_raise(array, dict, parameter_name="array")
         from ..receivable.media import MessageEntity
         from .files import InputFile
-
         data = InputMediaVideolike.validate_array(array)
         # 'type' is given by class type
         # 'media' is given by class type
@@ -1160,7 +1168,7 @@ class InputMediaAnimation(InputMediaVideolike):
     Parameters:
 
     :param media: File to send. Pass a file_id to send a file that exists on the Telegram servers (recommended), pass an HTTP URL for Telegram to get a file from the Internet, or pass "attach://<file_attach_name>" to upload a new one using multipart/form-data under <file_attach_name> name. More info on Sending Files »
-    :type  media: str|unicode|pytgbot.api_types.sendable.files.InputFile
+    :type  media: pytgbot.api_types.sendable.files.InputFile | str|unicode
 
 
     Optional keyword parameters:
@@ -1187,6 +1195,7 @@ class InputMediaAnimation(InputMediaVideolike):
     :type  duration: int
     """
 
+    # noinspection PyShadowingBuiltins
     def __init__(self, media, thumb=None, caption=None, parse_mode=None, caption_entities=None, width=None, height=None, duration=None):
         """
         Represents an animation file (GIF or H.264/MPEG-4 AVC video without sound) to be sent.
@@ -1197,7 +1206,7 @@ class InputMediaAnimation(InputMediaVideolike):
         Parameters:
 
         :param media: File to send. Pass a file_id to send a file that exists on the Telegram servers (recommended), pass an HTTP URL for Telegram to get a file from the Internet, or pass "attach://<file_attach_name>" to upload a new one using multipart/form-data under <file_attach_name> name. More info on Sending Files »
-        :type  media: str|unicode|pytgbot.api_types.sendable.files.InputFile
+        :type  media: pytgbot.api_types.sendable.files.InputFile | str|unicode
 
 
         Optional keyword parameters:
@@ -1223,10 +1232,9 @@ class InputMediaAnimation(InputMediaVideolike):
         :param duration: Optional. Animation duration
         :type  duration: int
         """
-        super(InputMediaAnimation, self).__init__('animation', media, thumb, caption, parse_mode, caption_entities, width, height, duration)
+        super(InputMediaAnimation, self).__init__(type='animation', media=media, thumb=thumb, caption=caption, parse_mode=parse_mode, caption_entities=caption_entities, width=width, height=height, duration=duration)
         from ..receivable.media import MessageEntity
         from .files import InputFile
-
         # 'type' is set by InputMediaVideolike base class
         # 'media' is set by InputMediaVideolike base class
         # 'thumb' is set by InputMediaVideolike base class
@@ -1252,6 +1260,8 @@ class InputMediaAnimation(InputMediaVideolike):
             return self._raw
         # end if
 
+        from ..receivable.media import MessageEntity
+        from .files import InputFile
         array = super(InputMediaAnimation, self).to_array()
 
         # 'type' given by superclass
@@ -1278,7 +1288,6 @@ class InputMediaAnimation(InputMediaVideolike):
         assert_type_or_raise(array, dict, parameter_name="array")
         from ..receivable.media import MessageEntity
         from .files import InputFile
-
         data = InputMediaVideolike.validate_array(array)
         # 'type' is given by class type
         # 'media' is given by class type
@@ -1350,7 +1359,7 @@ class InputMediaAudio(InputMediaPlayable):
     Parameters:
 
     :param media: File to send. Pass a file_id to send a file that exists on the Telegram servers (recommended), pass an HTTP URL for Telegram to get a file from the Internet, or pass "attach://<file_attach_name>" to upload a new one using multipart/form-data under <file_attach_name> name. More info on Sending Files »
-    :type  media: str|unicode|pytgbot.api_types.sendable.files.InputFile
+    :type  media: pytgbot.api_types.sendable.files.InputFile | str|unicode
 
 
     Optional keyword parameters:
@@ -1377,6 +1386,7 @@ class InputMediaAudio(InputMediaPlayable):
     :type  title: str|unicode
     """
 
+    # noinspection PyShadowingBuiltins
     def __init__(self, media, thumb=None, caption=None, parse_mode=None, caption_entities=None, duration=None, performer=None, title=None):
         """
         Represents an audio file to be treated as music to be sent.
@@ -1387,7 +1397,7 @@ class InputMediaAudio(InputMediaPlayable):
         Parameters:
 
         :param media: File to send. Pass a file_id to send a file that exists on the Telegram servers (recommended), pass an HTTP URL for Telegram to get a file from the Internet, or pass "attach://<file_attach_name>" to upload a new one using multipart/form-data under <file_attach_name> name. More info on Sending Files »
-       :type  media: str|unicode|pytgbot.api_types.sendable.files.InputFile
+        :type  media: pytgbot.api_types.sendable.files.InputFile | str|unicode
 
 
         Optional keyword parameters:
@@ -1413,10 +1423,9 @@ class InputMediaAudio(InputMediaPlayable):
         :param title: Optional. Title of the audio
         :type  title: str|unicode
         """
-        super(InputMediaAudio, self).__init__('audio', media, thumb, caption, parse_mode, caption_entities, duration)
+        super(InputMediaAudio, self).__init__(type='audio', media=media, thumb=thumb, caption=caption, parse_mode=parse_mode, caption_entities=caption_entities, duration=duration)
         from ..receivable.media import MessageEntity
         from .files import InputFile
-
         # 'type' is set by InputMediaPlayable base class
         # 'media' is set by InputMediaPlayable base class
         # 'thumb' is set by InputMediaPlayable base class
@@ -1444,6 +1453,8 @@ class InputMediaAudio(InputMediaPlayable):
             return self._raw
         # end if
 
+        from ..receivable.media import MessageEntity
+        from .files import InputFile
         array = super(InputMediaAudio, self).to_array()
 
         # 'type' given by superclass
@@ -1474,7 +1485,6 @@ class InputMediaAudio(InputMediaPlayable):
         assert_type_or_raise(array, dict, parameter_name="array")
         from ..receivable.media import MessageEntity
         from .files import InputFile
-
         data = InputMediaPlayable.validate_array(array)
         # 'type' is given by class type
         # 'media' is given by class type
@@ -1546,7 +1556,7 @@ class InputMediaDocument(InputMediaWithThumb):
     Parameters:
 
     :param media: File to send. Pass a file_id to send a file that exists on the Telegram servers (recommended), pass an HTTP URL for Telegram to get a file from the Internet, or pass "attach://<file_attach_name>" to upload a new one using multipart/form-data under <file_attach_name> name. More info on Sending Files »
-    :type  media: str|unicode
+    :type  media: pytgbot.api_types.sendable.files.InputFile | str|unicode
 
 
     Optional keyword parameters:
@@ -1567,6 +1577,7 @@ class InputMediaDocument(InputMediaWithThumb):
     :type  disable_content_type_detection: bool
     """
 
+    # noinspection PyShadowingBuiltins
     def __init__(self, media, thumb=None, caption=None, parse_mode=None, caption_entities=None, disable_content_type_detection=None):
         """
         Represents a general file to be sent.
@@ -1577,7 +1588,7 @@ class InputMediaDocument(InputMediaWithThumb):
         Parameters:
 
         :param media: File to send. Pass a file_id to send a file that exists on the Telegram servers (recommended), pass an HTTP URL for Telegram to get a file from the Internet, or pass "attach://<file_attach_name>" to upload a new one using multipart/form-data under <file_attach_name> name. More info on Sending Files »
-        :type  media: str|unicode|pytgbot.api_types.sendable.files.InputFile
+        :type  media: pytgbot.api_types.sendable.files.InputFile | str|unicode
 
 
         Optional keyword parameters:
@@ -1597,10 +1608,9 @@ class InputMediaDocument(InputMediaWithThumb):
         :param disable_content_type_detection: Optional. Disables automatic server-side content type detection for files uploaded using multipart/form-data. Always true, if the document is sent as part of an album.
         :type  disable_content_type_detection: bool
         """
-        super(InputMediaDocument, self).__init__('document', media, thumb, caption, parse_mode, caption_entities)
+        super(InputMediaDocument, self).__init__(type='document', media=media, thumb=thumb, caption=caption, parse_mode=parse_mode, caption_entities=caption_entities)
         from ..receivable.media import MessageEntity
         from .files import InputFile
-
         # 'type' is set by InputMediaWithThumb base class
         # 'media' is set by InputMediaWithThumb base class
         # 'thumb' is set by InputMediaWithThumb base class
@@ -1625,6 +1635,8 @@ class InputMediaDocument(InputMediaWithThumb):
             return self._raw
         # end if
 
+        from ..receivable.media import MessageEntity
+        from .files import InputFile
         array = super(InputMediaDocument, self).to_array()
 
         # 'type' given by superclass
@@ -1651,7 +1663,6 @@ class InputMediaDocument(InputMediaWithThumb):
         assert_type_or_raise(array, dict, parameter_name="array")
         from ..receivable.media import MessageEntity
         from .files import InputFile
-
         data = InputMediaWithThumb.validate_array(array)
         # 'type' is given by class type
         # 'media' is given by class type
