@@ -4,6 +4,18 @@ from luckydonaldUtils.exceptions import assert_type_or_raise
 from . import Sendable
 
 __author__ = 'luckydonald'
+__all__ = [
+    'PassportElementError',
+    'PassportElementErrorDataField',
+    'PassportElementErrorFrontSide',
+    'PassportElementErrorReverseSide',
+    'PassportElementErrorSelfie',
+    'PassportElementErrorFile',
+    'PassportElementErrorFiles',
+    'PassportElementErrorTranslationFile',
+    'PassportElementErrorTranslationFiles',
+    'PassportElementErrorUnspecified',
+]
 
 
 class PassportElementError(Sendable):
